@@ -33,9 +33,11 @@ LINKS = {
     },
     Lang.RO: {
         'models': {
-            'diacritics': {
-                "link": "https://nextcloud.readerbench.com/index.php/s/pfC25G64JgxcfZS/download",
-                "version": "https://nextcloud.readerbench.com/index.php/s/XmW7b3kLMbQtn5C/download"
+            'diacritice': {
+                'RoBERT_base+CNN': {
+                    "link": "https://nextcloud.readerbench.com/index.php/s/ZG6qSKwELj87pTF/download",
+                    "version": "https://nextcloud.readerbench.com/index.php/s/GRsJP7yFreeicaR/download"
+                }
             },
             'readme': {
                 "link": "https://nextcloud.readerbench.com/index.php/s/Sj94ysrmDDxX8YH/download",
@@ -65,6 +67,10 @@ LINKS = {
                 'link': 'https://nextcloud.readerbench.com/index.php/s/DeH4mBtZFajKRan/download',
                 'version': 'https://nextcloud.readerbench.com/index.php/s/MdMKFDFKJ5feMnN/download'
             },
+            'multi_cased_base': {
+                'link': 'https://nextcloud.readerbench.com/index.php/s/yGY3AoRYWR2McyD/download',
+                'version': 'https://nextcloud.readerbench.com/index.php/s/yWetLtdEz2D4i6f/download'
+            },
         },
         'wordnet': "https://nextcloud.readerbench.com/index.php/s/7tDka2CSGYeJqgC/download",
         'wordlists': {
